summaryrefslogtreecommitdiff
path: root/Objects/classobject.c
diff options
context:
space:
mode:
Diffstat (limited to 'Objects/classobject.c')
-rw-r--r--Objects/classobject.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/Objects/classobject.c b/Objects/classobject.c
index daa8157426..89cb3f7406 100644
--- a/Objects/classobject.c
+++ b/Objects/classobject.c
@@ -202,8 +202,8 @@ typeobject Instancetype = {
};
-/* And finally, here are class method objects */
-/* (Really methods of instances) */
+/* And finally, here are instance method objects
+ (accidentally called class methods) */
typedef struct {
OB_HEAD
@@ -283,7 +283,7 @@ classmethod_dealloc(cm)
typeobject Classmethodtype = {
OB_HEAD_INIT(&Typetype)
0,
- "class method",
+ "instance method",
sizeof(classmethodobject),
0,
classmethod_dealloc, /*tp_dealloc*/